-- Preset3D --

function love3D.preset.cube3D(sideLength, ox, oy, oz)
	local points = {}
	local polyTable = {}
	for i=0, 8 do
		local point = {}
		point.x = 0
		point.y = 0
		point.z = 0
		table.insert(points, point)
	end
	local s = sideLength/2
	points[1].x, points[1].y, points[1].z = -s, -s, -s
	points[2].x, points[2].y, points[2].z = s, -s, -s
	points[3].x, points[3].y, points[3].z = s, s, -s
	points[4].x, points[4].y, points[4].z = -s, s, -s
	points[5].x, points[5].y, points[5].z = -s, -s, s
	points[6].x, points[6].y, points[6].z = s, -s, s
	points[7].x, points[7].y, points[7].z = s, s, -s
	points[8].x, points[8].y, points[8].z = -s, s, s
	for i, v in ipairs(points) do
		v.x = v.x + ox
		v.y = v.y + oy
		v.z = v.z + oz
	end
	polyTable = {
	{1, 2, 3, 4, color = {}},
	{5, 6, 7, 8, color = {}},
	{3, 4, 7, 8, color = {}},
	{1, 2, 5, 6, color = {}},
	{2, 3, 6, 7, color = {}},
	{1, 4, 5, 8, color = {}}
	}
	return points, polyTable
end

function love3D.preset.triPyramid(sideLength, ox, oy, oz)
	local points = {}
	local polyTable = {}
	for i = 1, 4 do points[i] = { x = 0, y = 0, z = 0 } end
	local s = sideLength/2
	rt3, rt6 = math.sqrt(3), math.sqrt(6)
	points[1].x, points[1].y, points[1].z =  s,	-s/rt3,	-s/rt6
	points[2].x, points[2].y, points[2].z = -s, -s/rt3, -s/rt6
	points[3].x, points[3].y, points[3].z =  0, 2*s/rt3,-s/rt6
	points[4].x, points[4].y, points[4].z =  0, 0,		 3*s/rt6
	for i, v in ipairs(points) do
		v.x = v.x + ox
		v.y = v.y + oy
		v.z = v.z + oz
		end
	polyTable = {						-- left-hand rule!
	{1, 3, 2, color = {255,  0,  0}},
	{3, 4, 2, color = {  0,255,  0}},
	{1, 2, 4, color = {255,255,  0}},
	{1, 4, 3, color = {  0,  0,255}}
	}
	return points, polyTable
	end

function love3D.preset.triCube3D(sideLength, ox, oy, oz)
	local points = {}
	local polyTable = {}
	for i = 1, 8 do points[i] = { x = 0, y = 0, z = 0 } end
	local s = sideLength/2
	points[1].x, points[1].y, points[1].z = -s, -s, -s
	points[2].x, points[2].y, points[2].z =  s, -s, -s
	points[3].x, points[3].y, points[3].z =  s,  s, -s
	points[4].x, points[4].y, points[4].z = -s,  s, -s
	points[5].x, points[5].y, points[5].z = -s, -s,  s
	points[6].x, points[6].y, points[6].z =  s, -s,  s
	points[7].x, points[7].y, points[7].z =  s,  s,  s
	points[8].x, points[8].y, points[8].z = -s,  s,  s
	for i, v in ipairs(points) do
		v.x = v.x + ox
		v.y = v.y + oy
		v.z = v.z + oz
		end
	polyTable = {				-- uses left-hand rule!
		{1, 2, 3, color = {}},
		{1, 3, 4, color = {}},
		{1, 6, 2, color = {}},
		{1, 5, 6, color = {}},
		{5, 7, 6, color = {}},
		{5, 8, 7, color = {}},
		{4, 3, 7, color = {}},
		{4, 7, 8, color = {}},
		{2, 6, 7, color = {}},
		{2, 7, 3, color = {}},
		{5, 1, 4, color = {}},
		{5, 4, 8, color = {}}
		}
	return points, polyTable
	end

function love3D.preset.square(sideLength, ox, oy, oz)
	local points = {}
	local poly = {}
	for i=0, 4 do
		local point = {}
		point.x = 0
		point.y = 0
		point.z = 0
		table.insert(points, point)
	end
	local s = sideLength/2
	points[1].x, points[1].y, points[1].z = -s, -s, -s
	points[2].x, points[2].y, points[2].z = s, -s, -s
	points[3].x, points[3].y, points[3].z = s, s, -s
	points[4].x, points[4].y, points[4].z = -s, s, -s
	for i, v in ipairs(points) do
		v.x = v.x + ox
		v.y = v.y + oy
		v.z = v.z + oz
	end
	polyTable = {
	{1, 2, 3, 4, color = {}}
	}
	return points, poly
end
